::: polars_st
    options:
        show_object_full_path: false
        show_root_toc_entry: false
        members:
            - GeometryType
            - DimensionType
            - CoordinateType
            - PolarsGeometryType
            - PolarsDimensionType
            - PolarsCoordinateType
